package com.ruoyi.project.zjsgfa.mapper;

import java.util.List;
import com.ruoyi.project.zjsgfa.domain.JcxxJkzp;

/**
 * 基础信息-井控专篇Mapper接口
 * 
 * @author ruoyi
 * @date 2025-07-24
 */
public interface JcxxJkzpMapper 
{
    /**
     * 查询基础信息-井控专篇
     * 
     * @param id 基础信息-井控专篇主键
     * @return 基础信息-井控专篇
     */
    public JcxxJkzp selectJcxxJkzpById(Long id);

    /**
     * 查询基础信息-井控专篇列表
     * 
     * @param jcxxJkzp 基础信息-井控专篇
     * @return 基础信息-井控专篇集合
     */
    public List<JcxxJkzp> selectJcxxJkzpList(JcxxJkzp jcxxJkzp);

    /**
     * 新增基础信息-井控专篇
     * 
     * @param jcxxJkzp 基础信息-井控专篇
     * @return 结果
     */
    public int insertJcxxJkzp(JcxxJkzp jcxxJkzp);

    /**
     * 修改基础信息-井控专篇
     * 
     * @param jcxxJkzp 基础信息-井控专篇
     * @return 结果
     */
    public int updateJcxxJkzp(JcxxJkzp jcxxJkzp);

    /**
     * 删除基础信息-井控专篇
     * 
     * @param id 基础信息-井控专篇主键
     * @return 结果
     */
    public int deleteJcxxJkzpById(Long id);

    /**
     * 批量删除基础信息-井控专篇
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteJcxxJkzpByIds(Long[] ids);
}
